@@ -1,10 +1,13 @@
 # built-in
 from datetime import datetime
+from distutils.log import debug
 import os
 
 # third-party
 import numpy as np
 
+from epibox import config_debug
+
 
 def write_file(t, a_file, sync_param, time, fmt):
     write_acq_file(a_file, t, time, fmt)
@@ -15,7 +18,7 @@ def write_acq_file(a_file, t, time, fmt):
 
 
 def write_drift_log(filename, sync_param):
-
+    
     sync_time = sync_param['sync_time']
     
     if not sync_param['mode']:
@@ -24,7 +27,7 @@ def write_drift_log(filename, sync_param):
     else:
         filename.write('\n')
     
-    print('%s' % '  ' + sync_time)
+    # config_debug.log(('%s' % '  ' + sync_time))
 
 
 def write_annot_file(recording_name, annot):
@@ -35,9 +38,9 @@ def write_annot_file(recording_name, annot):
 
 
 def write_summary_file(recording_name):
-
+    
     duration = datetime.now() - datetime.strptime(os.path.split(recording_name)[1][1:-4], '%Y-%m-%d %H-%M-%S')
-    print(f'duration: {str(duration)}')
+    config_debug.log(f'duration: {str(duration)}')
 
     with open(os.path.join(os.path.split(recording_name)[0], 'summary' + '.txt'), 'a+') as file:
         file.write('{}  {}\n'.format(os.path.split(recording_name)[1], str(duration).split('.')[0]))
\ No newline at end of file
