@@ -31,3 +31,6 @@ class TestEpibox(unittest.TestCase):
         help_result = runner.invoke(cli.main, ['--help'])
         assert help_result.exit_code == 0
         assert '--help  Show this message and exit.' in help_result.output
+
+if __name__ == '__main__':
+    unittest.main()
\ No newline at end of file
